@@ -1,5 +1,5 @@
 "score.items"  <- 
- function (keys,items,totals=TRUE,ilabels=NULL, missing=TRUE, min=NULL,max=NULL,digits=2) {
+ function (keys,items,totals=FALSE,ilabels=NULL, missing=TRUE, min=NULL,max=NULL,digits=2) {
     keys <- as.matrix(keys)   #just in case they were not matrices to start with
     items <- as.matrix(items)
     item.means <- colMeans(items,na.rm=TRUE)
@@ -8,15 +8,16 @@
     if(missing) { miss.rep <- rowSums(is.na(items))
        item.means <- colMeans(items,na.rm=TRUE)
             miss <- which(is.na(items),arr.ind=TRUE)
-           items[miss]<- item.means[miss[,2]]}
+           items[miss]<- item.means[miss[,2]]}       #replace missing values with means
     n.keys <- dim(keys)[2]
     n.items <- dim(keys)[1]
     n.subjects <- dim(items)[1]
-     scores<- items %*%  keys  #this actually does all the work but doesn't handle missing
+     scores<- items %*%  keys  #this actually does all the work but doesn't handle missing values
     
-    scores<- items %*%  keys  #this actually does all the work
     slabels <- colnames(keys)
-    if (is.null(slabels)) {slabels<- paste("S",1:n.keys,sep="")}
+    if (is.null(slabels)) {
+    	if (totals) {slabels<- paste("S",1:n.keys,sep="")} else {
+    	             slabels <- paste("A",1:n.keys,sep="")} }
     colnames(scores) <- slabels  
     
     abskeys <- abs(keys)
@@ -36,11 +37,14 @@
    rownames(item.cor) <- ilabels
    correction <- (colSums(abs(keys)-(keys))/2)*(max+min)
    scores <- scores  + matrix(rep(correction,n.subjects),byrow=TRUE,nrow=n.subjects)
+   colnames(scores) <- slabels
    
-   if (!totals) {scores <- scores %*% diag(1/num.item)   #find averages
-                 colnames(scores) <- paste("A",1:n.keys,sep="") }
+   if (!totals) {
+    if(n.keys > 1) {scores <- scores %*% diag(1/num.item)   #find averages
+                  }  else
+                 {scores <- scores/num.item } }
     scale.cor <- correct.cor(cor.scales,t(alpha.scale))
    if (missing){results <-list(scores=scores,missing = miss.rep,alpha=round(alpha.scale,digits), av.r=round(av.r,digits), n.items = num.item,  item.cor = round(item.cor,digits),cor = round(cor.scales,digits) ,corrected = round(scale.cor,digits))} else{  
     results <- list(scores=scores,alpha=round(alpha.scale,digits), av.r=round(av.r,digits), n.items = num.item,  item.cor = round(item.cor,digits), cor = round(cor.scales,digits),corrected = round(scale.cor,digits))} 
  }
- 
+ #modified June 1 to add row names to items 
